@@ -27,6 +27,10 @@
 #include <QObject>
 #include <QPainter>
 #include <QWidget>
+#include <DWindowManagerHelper>
+#include <DForeignWindow>
+#include <QDebug>
+
 #include "main_window.h"
 #include <QVBoxLayout>
 #include <QProcess>
@@ -107,23 +111,34 @@ void MainWindow::initAttributes()
 
     selectAreaName = "";
 
+    createWinId();
+
     // Get all windows geometry.
     // Below code must execute before `window.showFullscreen,
     // otherwise deepin-screen-recorder window will add in window lists.
     QPoint pos = this->cursor().pos();
+    const qreal ratio = devicePixelRatioF();
     DScreenWindowsUtil* screenWin = DScreenWindowsUtil::instance(pos);
     screenRect = screenWin->backgroundRect();
-    this->move(screenRect.x(), screenRect.y());
+    screenRect = QRect(screenRect.topLeft() / ratio, screenRect.size());
+    this->move(static_cast<int>(screenRect.x() * ratio),
+               static_cast<int>(screenRect.y() * ratio));
     this->setFixedSize(screenRect.width(), screenRect.height());
-    
+
     windowManager = new DWindowManager();
     windowManager->setRootWindowRect(screenRect);
     QList<xcb_window_t> windows = windowManager->getWindows();
     rootWindowRect = windowManager->getRootWindowRect();
 
-    for (int i = 0; i < windows.length(); i++) {
-        windowRects.append(windowManager->adjustRectInScreenArea(windowManager->getWindowRect(windows[i])));
-        windowNames.append(windowManager->getWindowClass(windows[i]));
+    for (auto wid : DWindowManagerHelper::instance()->currentWorkspaceWindowIdList()) {
+        if (wid == winId()) continue;
+
+        DForeignWindow * window = DForeignWindow::fromWinId(wid);
+        if (window) {
+            window->deleteLater();
+            windowRects << Dtk::Wm::WindowRect { window->x(), window->y(), window->width(), window->height() };
+            windowNames << window->wmClass();
+        }
     }
 
     recordButtonLayout = new QVBoxLayout();
@@ -401,20 +416,12 @@ bool MainWindow::eventFilter(QObject *, QEvent *event)
             // Record select area name with window name if just click (no drag).
             if (!isFirstDrag) {
                 QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
-                for (int i = 0; i < windowRects.length(); i++) {
-                    int wx = windowRects[i].x;
-                    int wy = windowRects[i].y;
-                    int ww = windowRects[i].width;
-                    int wh = windowRects[i].height;
-                    int ex = mouseEvent->x();
-                    int ey = mouseEvent->y();
-                    if (ex > wx && ex < wx + ww && ey > wy && ey < wy + wh) {
-                        selectAreaName = windowNames[i];
-
+                for (auto it = windowRects.rbegin(); it != windowRects.rend(); ++it) {
+                    if (QRect(it->x, it->y, it->width, it->height).contains(mouseEvent->pos() + screenRect.topLeft())) {
+                        selectAreaName = windowNames[windowRects.rend() - it - 1];
                         break;
                     }
                 }
-
             } else {
                 // Make sure record area not too small.
                 recordWidth = recordWidth < RECORD_MIN_SIZE ? RECORD_MIN_SIZE : recordWidth;
@@ -507,22 +514,16 @@ bool MainWindow::eventFilter(QObject *, QEvent *event)
                 needRepaint = true;
             }
         } else {
-            for (int i = 0; i < windowRects.length(); i++) {
-                int wx = windowRects[i].x;
-                int wy = windowRects[i].y;
-                int ww = windowRects[i].width;
-                int wh = windowRects[i].height;
-                int ex = mouseEvent->x() + screenRect.x();
-                int ey = mouseEvent->y() + screenRect.y();
-
-                if (ex > wx && ex < wx + ww && ey > wy && ey < wy + wh) {
-                    recordX = wx - screenRect.x();
-                    recordY = wy - screenRect.y();
-                    recordWidth = ww;
-                    recordHeight = wh;
-                    
+            // Select the first window where the mouse is located
+            const qreal ratio = devicePixelRatioF();
+            const QPoint mousePoint = QCursor::pos();
+            for (auto it = windowRects.rbegin(); it != windowRects.rend(); ++it) {
+                if (QRect(it->x, it->y, it->width, it->height).contains(mousePoint)) {
+                    recordX = it->x - static_cast<int>(screenRect.x() * ratio);
+                    recordY = it->y - static_cast<int>(screenRect.y() * ratio);
+                    recordWidth = it->width;
+                    recordHeight = it->height;
                     needRepaint = true;
-
                     break;
                 }
             }
@@ -734,7 +735,17 @@ void MainWindow::startCountdown()
 {
     recordButtonStatus = RECORD_BUTTON_WAIT;
 
-    recordProcess.setRecordInfo(recordX, recordY, recordWidth, recordHeight, selectAreaName, rootWindowRect.width, rootWindowRect.height);
+    const qreal ratio = devicePixelRatioF();
+    const QPoint topLeft = geometry().topLeft();
+
+    QRect recordRect {
+        static_cast<int>(recordX * ratio + topLeft.x()),
+        static_cast<int>(recordY * ratio + topLeft.y()),
+        static_cast<int>(recordWidth * ratio),
+        static_cast<int>(recordHeight * ratio)
+    };
+
+    recordProcess.setRecordInfo(recordRect, selectAreaName);
     if (QSysInfo::currentCpuArchitecture().startsWith("x86")) {
         if (recordOptionPanel->isSaveAsGif()) {
             recordProcess.setRecordType(RecordProcess::RECORD_TYPE_GIF);
