@@ -2,27 +2,27 @@
 <context>
     <name>CountdownTooltip</name>
     <message>
-        <location filename="../src/countdown_tooltip.cpp" line="73"/>
-        <source>Click tray icon 
+        <location filename="../src/countdown_tooltip.cpp" line="78"/>
+        <source>Click the tray icon 
 or press the shortcut again to stop recording</source>
-        <translation>Clicca l&apos;icona sulla Tray
-o premi nuovamente la scorciatoia per stoppare la registrazione</translation>
+        <translation>Clicca sulla Tray
+o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main_window.cpp" line="67"/>
+        <location filename="../src/main_window.cpp" line="76"/>
         <source>Deepin screen recorder</source>
         <translation>Deepin screen recorder</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="121"/>
+        <location filename="../src/main_window.cpp" line="136"/>
         <source>Start recording</source>
         <translation>Inizia la registrazione</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="422"/>
+        <location filename="../src/main_window.cpp" line="454"/>
         <source>Select area</source>
         <translation>Seleziona l&apos;area</translation>
     </message>
@@ -30,22 +30,22 @@ o premi nuovamente la scorciatoia per stoppare la registrazione</translation>
 <context>
     <name>RecordProcess</name>
     <message>
-        <location filename="../src/record_process.cpp" line="137"/>
+        <location filename="../src/record_process.cpp" line="229"/>
         <source>deepin-screen-recorder</source>
         <translation>deepin-screen-recorder</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="185"/>
+        <location filename="../src/record_process.cpp" line="291"/>
         <source>View</source>
         <translation>Visualizza</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="195"/>
-        <source>Record finished</source>
-        <translation>Registrazione terminata</translation>
+        <location filename="../src/record_process.cpp" line="301"/>
+        <source>Recording finished</source>
+        <translation>Registrazione completata</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="196"/>
+        <location filename="../src/record_process.cpp" line="302"/>
         <source>Saved to</source>
         <translation>Salva in</translation>
     </message>
@@ -53,20 +53,11 @@ o premi nuovamente la scorciatoia per stoppare la registrazione</translation>
 <context>
     <name>StartTooltip</name>
     <message>
-        <location filename="../src/start_tooltip.cpp" line="45"/>
+        <location filename="../src/start_tooltip.cpp" line="48"/>
         <source>Click or drag to
 select the area to record</source>
         <translation>Clicca o trascina
 seleziona l&apos;area da registrare</translation>
     </message>
 </context>
-<context>
-    <name>WindowManager</name>
-    <message>
-        <location filename="../src/window_manager.cpp" line="150"/>
-        <location filename="../src/window_manager.cpp" line="169"/>
-        <source>Desktop</source>
-        <translation>Desktop</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
