@@ -2,8 +2,8 @@
 <context>
     <name>CountdownTooltip</name>
     <message>
-        <location filename="../src/countdown_tooltip.cpp" line="73"/>
-        <source>Click tray icon 
+        <location filename="../src/countdown_tooltip.cpp" line="78"/>
+        <source>Click the tray icon 
 or press the shortcut again to stop recording</source>
         <translation>点击托盘图标以停止录制
 或再次按下深度录屏快捷键</translation>
@@ -12,17 +12,17 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main_window.cpp" line="67"/>
+        <location filename="../src/main_window.cpp" line="76"/>
         <source>Deepin screen recorder</source>
         <translation>深度录屏</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="121"/>
+        <location filename="../src/main_window.cpp" line="136"/>
         <source>Start recording</source>
         <translation>开始录制</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="422"/>
+        <location filename="../src/main_window.cpp" line="454"/>
         <source>Select area</source>
         <translation>选择区域</translation>
     </message>
@@ -30,22 +30,22 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>RecordProcess</name>
     <message>
-        <location filename="../src/record_process.cpp" line="137"/>
+        <location filename="../src/record_process.cpp" line="229"/>
         <source>deepin-screen-recorder</source>
         <translation>深度录屏</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="185"/>
+        <location filename="../src/record_process.cpp" line="291"/>
         <source>View</source>
         <translation>查看</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="195"/>
-        <source>Record finished</source>
+        <location filename="../src/record_process.cpp" line="301"/>
+        <source>Recording finished</source>
         <translation>录制完毕</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="196"/>
+        <location filename="../src/record_process.cpp" line="302"/>
         <source>Saved to</source>
         <translation>保存在</translation>
     </message>
@@ -53,19 +53,10 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>StartTooltip</name>
     <message>
-        <location filename="../src/start_tooltip.cpp" line="45"/>
+        <location filename="../src/start_tooltip.cpp" line="48"/>
         <source>Click or drag to
 select the area to record</source>
         <translation>点击或拖拽来选择录制区域</translation>
     </message>
 </context>
-<context>
-    <name>WindowManager</name>
-    <message>
-        <location filename="../src/window_manager.cpp" line="150"/>
-        <location filename="../src/window_manager.cpp" line="169"/>
-        <source>Desktop</source>
-        <translation>桌面</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
